from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.sync_entity_type import SyncEntityType
from ..types import UNSET, Unset

T = TypeVar("T", bound="SyncAckDeleteDto")


@_attrs_define
class SyncAckDeleteDto:
    """
    Attributes:
        types (Union[Unset, list[SyncEntityType]]):
    """

    types: Union[Unset, list[SyncEntityType]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        types: Union[Unset, list[str]] = UNSET
        if not isinstance(self.types, Unset):
            types = []
            for types_item_data in self.types:
                types_item = types_item_data.value
                types.append(types_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if types is not UNSET:
            field_dict["types"] = types

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        types = []
        _types = d.pop("types", UNSET)
        for types_item_data in _types or []:
            types_item = SyncEntityType(types_item_data)

            types.append(types_item)

        sync_ack_delete_dto = cls(
            types=types,
        )

        sync_ack_delete_dto.additional_properties = d
        return sync_ack_delete_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
