from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="SyncAlbumToAssetDeleteV1")


@_attrs_define
class SyncAlbumToAssetDeleteV1:
    """
    Attributes:
        album_id (str):
        asset_id (str):
    """

    album_id: str
    asset_id: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        album_id = self.album_id

        asset_id = self.asset_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "albumId": album_id,
                "assetId": asset_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        album_id = d.pop("albumId")

        asset_id = d.pop("assetId")

        sync_album_to_asset_delete_v1 = cls(
            album_id=album_id,
            asset_id=asset_id,
        )

        sync_album_to_asset_delete_v1.additional_properties = d
        return sync_album_to_asset_delete_v1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
