from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="JobCountsDto")


@_attrs_define
class JobCountsDto:
    """
    Attributes:
        active (int):
        completed (int):
        delayed (int):
        failed (int):
        paused (int):
        waiting (int):
    """

    active: int
    completed: int
    delayed: int
    failed: int
    paused: int
    waiting: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        active = self.active

        completed = self.completed

        delayed = self.delayed

        failed = self.failed

        paused = self.paused

        waiting = self.waiting

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "active": active,
                "completed": completed,
                "delayed": delayed,
                "failed": failed,
                "paused": paused,
                "waiting": waiting,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        active = d.pop("active")

        completed = d.pop("completed")

        delayed = d.pop("delayed")

        failed = d.pop("failed")

        paused = d.pop("paused")

        waiting = d.pop("waiting")

        job_counts_dto = cls(
            active=active,
            completed=completed,
            delayed=delayed,
            failed=failed,
            paused=paused,
            waiting=waiting,
        )

        job_counts_dto.additional_properties = d
        return job_counts_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
